@@ -6,30 +6,20 @@
 
 //! # cqrs-es2
 //!
-//! **A lightweight, opinionated CQRS and event sourcing framework
-//! targeting serverless architectures.**
+//! **A Rust library providing lightweight CQRS and event sourcing
+//! framework.**
 //!
 //! [![Publish](https://github.com/brgirgis/cqrs-es2/actions/workflows/crates-io.yml/badge.svg)](https://github.com/brgirgis/cqrs-es2/actions/workflows/crates-io.yml)
 //! [![Test](https://github.com/brgirgis/cqrs-es2/actions/workflows/rust-ci.yml/badge.svg)](https://github.com/brgirgis/cqrs-es2/actions/workflows/rust-ci.yml)
-//! [![Crates.io](https://img.shields.io/crates/v/cqrs-es2)](https://crates.io/crates/cqrs-es2)
+//! [![Latest version](https://img.shields.io/crates/v/cqrs-es2)](https://crates.io/crates/cqrs-es2)
 //! [![docs](https://img.shields.io/badge/API-docs-blue.svg)](https://docs.rs/cqrs-es2)
+//! ![License](https://img.shields.io/crates/l/cqrs-es2.svg)
+//!
 //! ---
 //!
-//! ## Installation
-//!
-//! ```toml
-//! [dependencies]
-//! cqrs-es2 = "0.3.0"
-//! serde = { version = "^1.0.127", features = ["derive"] }
-//! serde_json = "^1.0.66"
-//! ```
-//!
 //! ## Usage
 //!
-//! Documentation [is available here](https://doc.rust-cqrs.org)
-//! along with an introduction to CQRS and event sourcing.
-//!
-//! Demo applications:
+//! Full fledged demo applications:
 //!
 //! - [RESTful](https://github.com/brgirgis/cqrs-restful-demo).
 //! - [gRPC](https://github.com/brgirgis/cqrs-grpc-demo).
@@ -39,9 +29,9 @@ pub use crate::{
     commands::*,
     errors::*,
     events::*,
-    framework::*,
     queries::*,
     stores::*,
+    test_framework::*,
 };
 
 // Errors module holds the library error types.
@@ -67,17 +57,11 @@ mod stores;
 // system.
 mod queries;
 
-// Framework provides the base framework and associated logic for
-// processing loading aggregates via an event store and subsequently
-// processing commands.
-mod framework;
-
-// Documentation items
-#[doc(hidden)]
-pub mod doc;
-
 /// Test provides a test framework for building a resilient test base
 /// around aggregates. A `TestFramework` should be used to build a
 /// comprehensive set of aggregate tests to verify your application
 /// logic (aka business rules).
-pub mod test;
+mod test_framework;
+
+#[doc(hidden)]
+pub mod example_impl;
